summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/ifc/connection/_XAcceptor.java
diff options
context:
space:
mode:
Diffstat (limited to 'qadevOOo/tests/java/ifc/connection/_XAcceptor.java')
-rw-r--r--qadevOOo/tests/java/ifc/connection/_XAcceptor.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/qadevOOo/tests/java/ifc/connection/_XAcceptor.java b/qadevOOo/tests/java/ifc/connection/_XAcceptor.java
index 5b0ce68803d9..40b7fba2fbae 100644
--- a/qadevOOo/tests/java/ifc/connection/_XAcceptor.java
+++ b/qadevOOo/tests/java/ifc/connection/_XAcceptor.java
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMethodTest {
/**
* Calls <code>accept()</code> method in a separate thread.
* Then stores exception thrown by call if it occured, or
* return value.
*/
protected class AcceptorThread extends Thread {
/**
* If exception occured during method call it is
* stored in this field.
*/
public Exception ex = null ;
@@ -179,7 +179,7 @@ public class _XAcceptor extends MultiMethodTest {
acception.acceptedCall.getDescription()) ;
} else {
if (acception.ex != null) {
- log.println("Exception occured in accept() thread :") ;
+ log.println("Exception occurred in accept() thread :") ;
acception.ex.printStackTrace(log) ;
}
@@ -299,7 +299,7 @@ public class _XAcceptor extends MultiMethodTest {
} else {
if (acception.ex != null) {
- log.println("Exception occured in accept() thread :") ;
+ log.println("Exception occurred in accept() thread :") ;
acception.ex.printStackTrace(log) ;
result = false ;
} else {
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMethodTest {
/**
* Calls <code>accept()</code> method in a separate thread.
- * Then stores exception thrown by call if it occured, or
+ * Then stores exception thrown by call if it occurred, or
* return value.
*/
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMethodTest {
protected class AcceptorThread extends Thread {
/**
- * If exception occured during method call it is
+ * If exception occurred during method call it is
* stored in this field.
*/